@@ -76,8 +76,17 @@ var (
 	CABFBRs_1_7_9_Date                               = time.Date(2021, time.August, 16, 0, 0, 0, 0, time.UTC)
 	CABFBRs_1_8_0_Date                               = time.Date(2021, time.August, 25, 0, 0, 0, 0, time.UTC)
 	CABFBRs_2_0_0_Date                               = time.Date(2023, time.September, 15, 0, 0, 0, 0, time.UTC)
+	CABFBRs_2_0_1_Date                               = time.Date(2024, time.March, 15, 0, 0, 0, 0, time.UTC)
+	CABFBRs_2_0_2_Date                               = time.Date(2024, time.January, 8, 0, 0, 0, 0, time.UTC)
+	CABFBRs_2_0_3_Date                               = time.Date(2024, time.April, 15, 0, 0, 0, 0, time.UTC)
+	CABFBRs_2_0_4_Date                               = time.Date(2024, time.May, 15, 0, 0, 0, 0, time.UTC)
+	CABFBRs_2_0_5_Date                               = time.Date(2024, time.July, 1, 0, 0, 0, 0, time.UTC)
+	CABFBRs_2_0_6_Date                               = time.Date(2024, time.August, 6, 0, 0, 0, 0, time.UTC)
+	CABFBRs_2_0_7_Date                               = time.Date(2024, time.September, 6, 0, 0, 0, 0, time.UTC)
+	CABFBRs_2_0_8_Date                               = time.Date(2024, time.October, 2, 0, 0, 0, 0, time.UTC)
 	NoReservedDomainLabelsDate                       = time.Date(2021, time.October, 1, 0, 0, 0, 0, time.UTC)
 	CABFBRs_OU_Prohibited_Date                       = time.Date(2022, time.September, 1, 0, 0, 0, 0, time.UTC)
+	SC16EffectiveDate                                = time.Date(2019, time.April, 16, 0, 0, 0, 0, time.UTC)
 	SC17EffectiveDate                                = time.Date(2019, time.June, 21, 0, 0, 0, 0, time.UTC)
 	CABF_SMIME_BRs_1_0_0_Date                        = time.Date(2023, time.September, 1, 0, 0, 0, 0, time.UTC)
 	// Enforcement date of CRL reason codes from Ballot SC 061
@@ -86,6 +95,7 @@ var (
 	SC62EffectiveDate = time.Date(2023, time.September, 15, 0, 0, 0, 0, time.UTC)
 	// Date when section 9.2.8 of CABF EVG became effective
 	CABFEV_Sec9_2_8_Date = time.Date(2020, time.January, 31, 0, 0, 0, 0, time.UTC)
+	CABF_CS_BRs_1_2_Date = time.Date(2019, time.August, 13, 0, 0, 0, 0, time.UTC)
 )
 
 var (
